# Info

 **SG Analytics Data API enables user to easily request quotations and descriptions over more than 500k intruments** covering a large cross asset scope: Equity, Bonds, Credit, Forex, Commodities, Fixing (Coming soon) ... 

Data come from either SG research and SG trading desks or external sources such as ICAP or Markit.

The Market Data Analytics API provides endpoints to retrieve:
- available descriptions and indicators for each asset
- available assets using enhanced criteria and filters.
- Historical quotes
- Intraday quotes
- Real time data (user needs privilege rights)

For more informations fell free to take a look at the [swagger](https://analytics-api.sgmarkets.com/data/swagger/ui/index#/)

# Contacts
### Python:

+ FERRET Kevin MarkGrsRfcRat  
kevin.ferret@sgcib.com  
+44 20 7676 7073  
+ DRIGOUT Gilles MarkGrsStgCaq  
gilles.drigout@sgcib.com  
+33 1 42 13 74 50  
+ NEFATI Marwen MarkGrsStgCaq  
marwen.nefati@sgcib.com  
+33 1 58 98 15 06  
+ BORDERIES Olivier GbisCdo  
olivier.borderies@sgcib.com  
+33 1 42 13 61 04  


### API & Analytics

+ CARISTAN Aurelien MarkAsiDir  
aurelien.caristan@sgcib.com  
+81 3 6777 8016  
+ RIVET Nicolas GbisCdo  
nicolas.rivet@sgcib.com  
+33 1 57 29 04 58  

### Research

#### Rates & Derivatives:

+ KURPIEL Adam MarkGrsRfcRat  
Adam.KURPIEL@sgcib.com  
+33 1 42 13 63 42  
+ FERRET Kevin MarkGrsRat  
kevin.ferret@sgcib.com  
+44 20 7676 7073  
+ BRAIZINHA Bruno MarkGrsRat  
bruno.braizinha@sgcib.com  
+44 20 7676 7073  

#### X-asset Quant:

+ UNGARI Sandrine MarkGrsStgCaq  
sandrine.ungari@sgcib.com  
+44 20 7762 5214  
+ DRIGOUT Gilles MarkGrsStgCaq  
gilles.drigout@sgcib.com  
+33 1 42 13 74 50  
+ NEFATI Marwen MarkGrsStgCaq  
marwen.nefati@sgcib.com  
+33 1 58 98 15 06  

#### Forex:
+ KORBER Olivier MarkGrsRfcFrx  
olivier.korber@sgcib.com  
+33 1 42 13 32 88  

#### Equity Derivatives:
+ CASSOT Vincent MarkGrsEqtVol  
vincent.cassot@sgcib.com  
+33 1 42 13 59 55  

#### Equity Quant:
+ LAPTHORNE Andrew MarkGrsEqtQua  
andrew.lapthorne@sgcib.com  
+44 20 7762 5762  
+ OIKONOMOU Georgio MarkGrsEqtQua  
georgio.oikonomou@sgcib.com  
+44 20 7762 5261  

#### Credit:
+ STEAR Guy MarkGRSRfcCreStr  
guy.stear@sgcib.com  
+33 1 42 13 30 53  







